;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;; style.el                 ;;;;
;;;; purely aesthetic changes ;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; Prettify
(global-prettify-symbols-mode 1)

;; Font
(let ((fontName "Fira Code Retina-10"))
  (set-face-attribute 'default t :font fontName)
  (set-face-attribute 'default nil :font fontName))

;; Highlight long lines
(setq whitespace-line-column 100)
(setq whitespace-style '(face lines-tail))
(add-hook 'prog-mode-hook 'whitespace-mode)

;; Line numbers
(setq display-line-numbers-type 'relative)
(add-hook 'prog-mode-hook 'display-line-numbers-mode)

;; Tool bar mode
(menu-bar-mode -1)
(tool-bar-mode -1)
(toggle-scroll-bar -1)

;; Images
(setq image-use-external-converter t)

;; Theme
(load-theme 'solarized-light t)

;; Dashboard
(setq inhibit-splash-screen t)
(setq inhibit-startup-message t)

(require 'dashboard)
(dashboard-setup-startup-hook)

(setq dashboard-center-content t)

(setq dashboard-startup-banner (path "style/evil_logo.png"))
(setq dashboard-banner-logo-title "Welcome to EVIL")
(setq dashboard-set-heading-icons t)
(setq dashboard-set-file-icons t)
(setq dashboard-show-shortcuts nil)
(setq dashboard-filter-agenda-entry 'dashboard-no-filter-agenda)
(setq dashboard-footer-messages
      '("The one true editor!"
	"Who the hell uses VIM anyway? Go EVIL!"
	"Happy coding!"
	"VI VI VI, the editor of the beast"
	"While any text editor can save your files, only EVIL can save your soul"
	"λf. (λx. f (x x)) (λx. f (x x))"))

(when (display-graphic-p)
  (require 'all-the-icons))

;; Modeline
(require 'doom-modeline)
(doom-modeline-mode 1)
(setq doom-modeline-hud 1)

(custom-set-faces
 '(mode-line          ((t (:underline nil :overline nil))))
 '(mode-line-inactive ((t (:underline nil :overline nil)))))

;; Dired
(add-hook 'dired-mode-hook 'all-the-icons-dired-mode)

;; Org
(require 'org-superstar)
(add-hook 'org-mode-hook (lambda ()
			   (org-superstar-mode 1)
			   (org-fragtog-mode 1)
			   (org-indent-mode 1)
			   (visual-line-mode)
			   (writeroom-mode)))
(setq org-format-latex-options '(:scale 1.5))
(setq org-agenda-start-on-weekday 1)
